@@ -1,5 +1,7 @@
 package Getopt::Flex;
-our $VERSION = '1.02';
+BEGIN {
+  $Getopt::Flex::VERSION = '1.03';
+}
 
 # ABSTRACT: Option parsing, done different.
 
@@ -619,7 +621,7 @@ Getopt::Flex - Option parsing, done different.
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -647,13 +649,14 @@ version 1.02
 
 =head1 DESCRIPTION
 
-Getopt::Flex is an object-oriented way to go about option parsing.
-Creating an option specification is easy and declarative, and
-configuration is optional and defaults to a few, smart parameters.
-Generally, it adheres to the POSIX syntax with GNU extensions for
-command line options. As a result, options may be longer than a
-single letter, and would begin with "--". Support also exists
-for bundling of command line options and using switches without
+Getopt::Flex makes defining and documenting command line options in
+your program easy. It has a consistent object-oriented interface. 
+Creating an option specification is declarative and configuration 
+is optional and defaults to a few, smart parameters. Generally,
+it adheres to the POSIX syntax with GNU extensions for command 
+line options. As a result, options may be longer than a single 
+letter, and may begin with "--". Support also exists for 
+bundling of command line options and using switches without
 regard to their case, but these are not enabled by defualt.
 
 Getopt::Flex is an alternative to other modules in the Getopt::
